@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model;
-$Config::Model::VERSION = '2.108';
+$Config::Model::VERSION = '2.109';
 use strict ;
 use warnings;
 use 5.10.1;
@@ -329,8 +329,7 @@ sub instance_names {
 # into element description.
 
 my @legal_params_to_move = (
-    qw/read_config  read_config_dir
-       write_config write_config_dir/,    # read/write stuff
+    qw/read_config write_config rw_config/,    # read/write stuff
 
     # this parameter is filled by class generated by a program. It may
     # be used to avoid interactive edition of a generated model
@@ -411,7 +410,7 @@ sub include_backend {
         # includes (and normalization). Is already a dclone
         my $included_model = $self->get_model($included_class);
 
-        foreach my $rw (qw/read_config write_config config_dir/) {
+        foreach my $rw (qw/rw_config read_config write_config config_dir/) {
             if ($target_model->{$rw} and $included_model->{$rw}) {
                 my $msg = "Included $rw from $included_class cannot clobber "
                     . "existing data in $class_name";
@@ -479,15 +478,14 @@ sub normalize_class_parameters {
         $normalized_model->{include} = delete $normalized_model->{inherit};
     }
 
-    # get data read/write information (if any)
-    $model->{read_config_dir} = $model->{write_config_dir} = delete $normalized_model->{config_dir}
-        if defined $normalized_model->{config_dir};
-
     foreach my $info (@legal_params_to_move) {
         next unless defined $normalized_model->{$info};
         $model->{$info} = delete $normalized_model->{$info};
     }
 
+    # first deal with perl file and cds_file backend
+    $self->translate_legacy_backend_info( $config_class_name, $model );
+
     # handle accept parameter
     my @accept_list;
     my %accept_hash;
@@ -683,6 +681,39 @@ sub translate_legacy_info {
     ) if $legacy_logger->is_debug;
 }
 
+# TODO: use 'warn' for show_legacy_issue once all models are updated (mid October 2017 ?)
+# TODO: use 'die' mid November 2017
+sub translate_legacy_backend_info {
+    my ( $self, $config_class_name, $model ) = @_;
+
+    my $multi_backend = 0;
+    foreach my $config (qw/read_config write_config/) {
+        my $ref = $model->{$config};
+        if ($ref and ref($ref) eq 'ARRAY') {
+            if (@$ref == 1) {
+                $model->{$config} = $ref->[0];
+            }
+            elsif (@$ref > 1){
+                $self->show_legacy_issue("$config_class_name $config: multiple backends are deprecated", 'note');
+                $multi_backend++;
+            }
+        }
+    }
+
+    if ($model->{read_config}) {
+        $self->show_legacy_issue("$config_class_name: read_config specification is deprecated, please move in rw_config", 'note');
+        $model->{rw_config} = delete $model->{read_config} unless $multi_backend;
+    }
+
+    if ($model->{write_config}) {
+        $self->show_legacy_issue("$config_class_name: write_config specification is deprecated, please merge with read_config and move in rw_config", 'note');
+        if (not $multi_backend) {
+            map {$model->{rw_config}{$_} = $model->{write_config}{$_} } keys %{$model->{write_config}} ;
+            delete $model->{write_config};
+        }
+    }
+}
+
 sub translate_cargo_info {
     my $self              = shift;
     my $config_class_name = shift;
@@ -717,15 +748,14 @@ sub translate_cargo_info {
     ) if $legacy_logger->is_debug;
 }
 
-# TODO: set to die In September 2016
 sub translate_id_names {
     my $self              = shift;
     my $config_class_name = shift;
     my $elt_name          = shift;
     my $info              = shift;
-    $self->translate_name( $config_class_name, $elt_name, $info, 'allow',      'allow_keys',       'warn' );
-    $self->translate_name( $config_class_name, $elt_name, $info, 'allow_from', 'allow_keys_from',  'warn' );
-    $self->translate_name( $config_class_name, $elt_name, $info, 'follow',     'follow_keys_from', 'warn' );
+    $self->translate_name( $config_class_name, $elt_name, $info, 'allow',      'allow_keys',       'die' );
+    $self->translate_name( $config_class_name, $elt_name, $info, 'allow_from', 'allow_keys_from',  'die' );
+    $self->translate_name( $config_class_name, $elt_name, $info, 'follow',     'follow_keys_from', 'die' );
 }
 
 sub translate_name {
@@ -1781,7 +1811,7 @@ Config::Model - Create tools to validate, migrate and edit configuration files
 
 =head1 VERSION
 
-version 2.108
+version 2.109
 
 =head1 SYNOPSIS
 
@@ -1808,9 +1838,9 @@ version 2.108
  $model ->create_config_class (
    name => "MiniModel",
    element => [ [qw/foo bar baz/ ] => { type => 'leaf', value_type => 'uniline' }, ],
-   read_config => { backend => 'IniFile', auto_create => 1,
-                    config_dir => '.', file => 'mini.ini',
-                  }
+   rw_config => { backend => 'IniFile', auto_create => 1,
+                  config_dir => '.', file => 'mini.ini',
+                }
  ) ;
 
  # create instance (Config::Model::Instance object)
@@ -1832,9 +1862,9 @@ version 2.108
  $ mkdir -p lib/Config/Model/models/
  $ echo "[ { name => 'MiniModel', \
              element => [ [qw/foo bar baz/ ] => { type => 'leaf', value_type => 'uniline' }, ], \
-             read_config => { backend => 'IniFile', auto_create => 1, \
-                              config_dir => '.', file => 'mini.ini', \
-                            } \
+             rw_config => { backend => 'IniFile', auto_create => 1, \
+                            config_dir => '.', file => 'mini.ini', \
+                          } \
            } \
          ] ; " > lib/Config/Model/models/MiniModel.pl
  # require App::Cme
