@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Any;
-$Config::Model::Backend::Any::VERSION = '2.108';
+$Config::Model::Backend::Any::VERSION = '2.109';
 use Carp;
 use strict;
 use warnings;
@@ -187,7 +187,7 @@ Config::Model::Backend::Any - Virtual class for other backends
 
 =head1 VERSION
 
-version 2.108
+version 2.109
 
 =head1 SYNOPSIS
 
@@ -279,23 +279,23 @@ L<Config::Model::Node> specification.
 Let's say your new backend is C<Config::Model::Backend::Foo>. This new backend
 can be specified with:
 
- read_config  => [ {
+ rw_config  => {
     backend    => 'Foo' , # can also be 'foo'
     config_dir => '/etc/cfg_dir'
     file       => 'foo.conf', # optional
- }]
+ }
 
 (The backend class name is constructed with C<ucfirst($backend_name)>)
 
-C<read_config> can also have custom parameters that are passed
+C<rw_config> can also have custom parameters that are passed
 verbatim to C<Config::Model::Backend::Foo> methods:
 
- read_config  => [ {
+ rw_config  => {
     backend    => 'Foo' , # can also be 'foo'
     config_dir => '/etc/cfg_dir'
     file       => 'foo.conf', # optional
     my_param   => 'my_value',
- } ]
+ }
 
 C<Config::Model::Backend::Foo> class must inherit (extend)
 L<Config::Model::Backend::Any> and is expected to provide the
